@@ -33,7 +33,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
- * $Id: chalib.c,v 1.18.4.1 2001/06/21 05:37:36 masayu-a Exp $
+ * $Id: chalib.c,v 1.18.4.2 2002/01/05 07:05:33 kazuma-t Exp $
  */
 
 #include "chalib.h"
@@ -46,7 +46,6 @@
 int Cha_cost_width = -1;
 enum cha_lang Cha_lang = CHASEN_LANG_JA;
 enum cha_encode Cha_encode = CHASEN_ENCODE_EUCJP;
-chasen_tok_t *Cha_tokenizer;
 
 static int cost_width0;
 
@@ -396,7 +395,7 @@ chasen_command(char *comm)
 	 * ɲäñintեɲ 
 	 */
 	sprintf(tmpstr, "%s.int", patdic_filename[obj_dic_no]);
-	of = cha_fopen(tmpstr, "a", 1);
+	of = cha_fopen(tmpstr, "ab", 1);
 	fputs(arg, of);
 	fputc(0, of);
 	printf("add [%s] at %ld\n", arg, new_word_index);
@@ -479,12 +478,6 @@ chasen_sparse_main(char *input, FILE * output)
 	return 0;
     }
 
-    /*
-     * initialize the tokenizer
-     */
-    Cha_tokenizer = cha_tok_new(Cha_lang, Cha_encode);
-    cha_tok_set_annotation(Cha_tokenizer, Cha_anno_info);
-
     /*
      * ޥɡ󥿥ץ꥿ 
      */
@@ -527,7 +520,6 @@ chasen_sparse_main(char *input, FILE * output)
 	    input = crlf + 1;
     }
 
-    cha_tok_delete(Cha_tokenizer);
 
     return 0;
 }
