@@ -1,5 +1,5 @@
 /*
- * dic.c -- library for dictionary
+ * dic.c -- library for parsing dictionary
  *
  * Copyright (C) 2000, 2001,  Nara Institute of Science and Technology
  *                           
@@ -33,57 +33,77 @@
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
- * $Id: dic.c,v 1.3 2001/02/14 00:20:52 masayu-a Exp $
+ * $Id: dic.c,v 1.5 2001/03/15 21:25:48 masayu-a Exp $
  */
 #include "chalib.h"
 
-/* ե̾ */
-SUFARY *Suf_dicfile[PAT_DIC_NUM];  /* dictionary name (SUFDIC) */
-pat_t *Pat_dicfile[PAT_DIC_NUM];   /* dictionary name (PATDIC) */
+SUFARY *Suf_dicfile[PAT_DIC_NUM];	/* dictionary (SUFDIC) */
+pat_t *Pat_dicfile[PAT_DIC_NUM];	/* dictionary (PATDIC) */
 int Suf_ndicfile = 0;
 int Pat_ndicfile = 0;
 
-void cha_get_mrph_data(mrph2_t *mrph, char *pbuf, char *target)
+void
+cha_get_mrph_data(mrph2_t * mrph, char *pbuf, char *target)
 {
     unsigned char *p = pbuf;
 
-    mrph->midasi = target;  /* surfacr form */
-    mrph->is_undef = 0;     /* unseen word or not */
+    mrph->midasi = target;	/* surface form */
+    mrph->is_undef = 0;		/* unseen word or not */
 
-    /* ФĹ */ /* the length of surface form */
-    while (*p++)
-      ;
-    mrph->base_length = mrph->length = (char *)p - pbuf - 1;
-    /* ɤ */  /* Japanese reading */
+    /*
+     * ФĹ the length of surface form
+     */
+    while (*p++);
+    mrph->base_length = mrph->length = (char *) p - pbuf - 1;
+    /*
+     * ɤ Japanese reading 
+     */
     mrph->yomi = p;
-    while (*p++)
-      ;
-    /* ȯ */ /* Japanese pronunciation */
+    while (*p++);
+    /*
+     * ȯ Japanese pronunciation 
+     */
     mrph->pron = p;
-    while (*p++)
-      ;
-    /*  */ /* base form */
+    while (*p++);
+    /*
+     *  infinitive form 
+     */
     mrph->base = p;
-    while (*p++)
-      ;
-    /* ̣ */ /* semantic information */
+    while (*p++);
+    /*
+     * ̣ semantic information 
+     */
     mrph->info = p;
-    while (*p++)
-      ;
+    while (*p++);
 
-    /* ʻʬ No. */ /* POS number */
-    mrph->hinsi = (p[0]-CHAINT_OFFSET)*CHAINT_SCALE + p[1]-CHAINT_OFFSET;
+    /*
+     * ʻʬ POS number 
+     */
+    mrph->hinsi =
+	(p[0] - CHAINT_OFFSET) * CHAINT_SCALE + p[1] - CHAINT_OFFSET;
     p += 2;
-    /* ѷ No. */ /* Conjugation type */
+    /*
+     * ѷ Conjugation type 
+     */
     mrph->ktype = *p++ - CHAINT_OFFSET;
-    /* ѷ No. */ /* Conjugation form */
+    /*
+     * ѷ Conjugation form 
+     */
     mrph->kform = *p++ - CHAINT_OFFSET;
-    /* Ť */ /* cost for morpheme */
-    mrph->weight = (p[0]-CHAINT_OFFSET)*CHAINT_SCALE + p[1]-CHAINT_OFFSET;
+    /*
+     * Ť cost for morpheme 
+     */
+    mrph->weight =
+	(p[0] - CHAINT_OFFSET) * CHAINT_SCALE + p[1] - CHAINT_OFFSET;
     p += 2;
-    /* ³ơֹ֥ */  /* the number for connection matrix */
-    mrph->con_tbl = (p[0]-CHAINT_OFFSET)*CHAINT_SCALE + p[1]-CHAINT_OFFSET;
+    /*
+     * ³ơֹ֥ the number for connection matrix 
+     */
+    mrph->con_tbl =
+	(p[0] - CHAINT_OFFSET) * CHAINT_SCALE + p[1] - CHAINT_OFFSET;
     p += 2;
-    /* ʣ */  /* compound words information */
-    mrph->comp = p;
+    /*
+     * ʣ  compound words information 
+     */
+    mrph->compound = p;
 }
