@@ -1,7 +1,7 @@
 /*
  * Big Endian <-> Host byte order converter
  *
- * $Id: htobe.h,v 1.1.2.2 2001/03/21 18:01:40 masayu-a Exp $
+ * $Id: htobe.h,v 1.1.2.2.2.1 2002/01/05 07:05:33 kazuma-t Exp $
  */
 
 #include "config.h"
@@ -11,9 +11,6 @@
 
 #ifndef WORDS_BIGENDIAN
 #ifdef HAVE_HTONL
-#if HAVE_WINSOCK2_H
-#include <winsock2.h> /* MSWindows htonl() etc */
-#endif /* HAVE_WINSOCK2_H */
 #if HAVE_SYS_PARAM_H
 #include <sys/param.h> /* FreeBSD htonl() etc */
 #endif /* HAVE_SYS_PARAM_H */
