@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
  * Modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp> Sep. 1996
- * $Id: init.c,v 1.12 2001/03/15 21:25:48 masayu-a Exp $
+ * $Id: init.c,v 1.12.4.1 2002/01/05 07:05:33 kazuma-t Exp $
  */
 
 #include "chalib.h"
@@ -65,6 +65,8 @@ int Cha_output_iscompound = 1;
 char *Cha_bos_string = "";
 char *Cha_eos_string = "EOS\n";
 
+chasen_tok_t *Cha_tokenizer;
+
 extern int Suf_ndicfile;
 extern int Pat_ndicfile;
 
@@ -366,4 +368,10 @@ cha_init(void)
     for (i = 0; i < Cha_undef_info_num; i++)
 	Cha_undef_info[i].con_tbl =
 	    cha_check_table_for_undef(Cha_undef_info[i].hinsi);
+
+    /*
+     * initialize the tokenizer
+     */
+    Cha_tokenizer = cha_tok_new(Cha_lang, Cha_encode);
+    cha_tok_set_annotation(Cha_tokenizer, Cha_anno_info);
 }
