@@ -37,17 +37,13 @@
  * 1990/12/14/Fri       Yutaka MYOKI(Nagao Lab., KUEE)
  * 1990/12/25/Tue       Modified
  * Oct. 1996       A.Kitauchi <akira-k@is.aist-nara.ac.jp>
- * $Id: iotool.c,v 1.11.4.1 2001/06/24 06:19:02 taku-ku Exp $
+ * $Id: iotool.c,v 1.11.4.4 2002/01/08 07:16:38 taku-ku Exp $
  */
 #include <stdio.h>
 #include <stdarg.h>
 #include "chadic.h"
 #include "config.h"
 
-#ifdef HAVE_WINDOWS_H
-#include <windows.h>
-#endif
-
 #ifdef PATHTYPE_MSDOS
 #define RCFILE "\\chasenrc"
 #define RC2FILE "\\chasen2rc"
@@ -534,12 +530,7 @@ cha_fopen_rcfile(void)
     /*
      * RCPATH in rcpath.h 
      */
-#if defined HAVE_WINDOWS_H && defined _WIN32
-    GetPrivateProfileString("chasenrc", "chasenrc", RCPATH,
-                          chasenrc_path, sizeof(chasenrc_path), "chasen.ini");
-#else
     strcpy(chasenrc_path, RCPATH);
-#endif
 
     if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
 	return fp;
