@@ -38,7 +38,7 @@
  * NOTE: An idea of these procedures are taken from youhcan's jutils.c
  *       for wais-japanese
  * 
- * $Id: jfgets.c,v 1.8 2001/03/08 13:59:23 kazuma-t Exp $
+ * $Id: jfgets.c,v 1.8.4.1 2002/01/05 07:05:34 kazuma-t Exp $
  */
 
 
@@ -183,6 +183,7 @@ cha_fget_line(char *buffer, int bufsize, FILE * stream)
     if (kanji1) {
 	*tmp++ = kanji1;
 	kanji1 = 0;
+	bufsize--;
     }
 
     if (fgets(tmp, bufsize, stream) == NULL)
@@ -196,6 +197,9 @@ cha_fget_line(char *buffer, int bufsize, FILE * stream)
 	kanji1 = tmp_buf[last];
 	tmp_buf[last] = 0;
     }
+    /*
+     * but it's more better to use ungetc()?
+     */
 
     /*
      * for server mode 
