@@ -35,13 +35,14 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
  * 1990/12/17/Mon       Yutaka MYOKI(Nagao Lab., KUEE)
- * $Id: katuyou.c,v 1.8 2001/03/12 22:05:26 masayu-a Exp $
+ * $Id: katuyou.c,v 1.8.4.1 2002/02/05 13:42:07 akira-k Exp $
  */
 
 #include "chadic.h"
 
 ktype_t Cha_type[TYPE_NUM];
 kform_t Cha_form[TYPE_NUM][FORM_NUM];
+char *Cha_base_form_str = NULL;
 
 /*
  * read_type_form
@@ -58,6 +59,15 @@ read_type_form(FILE * fp)
 	Cha_type[i].name = cha_strdup(cha_s_atom(cha_car(cell1)));
 	Cha_type[i].basic = 0;
 	cell1 = cha_car(cha_cdr(cell1));
+
+	/* base form string */
+	if (strmatch3(Cha_type[i].name, JSTR_BASE_FORM_STR,
+		      ESTR_BASE_FORM_STR1, ESTR_BASE_FORM_STR2)) {
+	    Cha_base_form_str = cha_strdup(cha_s_atom(cell1));
+	    i--;
+	    continue;
+	}
+
 	for (j = 1; !nullp(cell2 = cha_car(cell1));
 	     cell1 = cha_cdr(cell1), j++) {
 	    /*
@@ -65,8 +75,10 @@ read_type_form(FILE * fp)
 	     */
 	    Cha_form[i][j].name = cha_strdup(cha_s_atom(cha_car(cell2)));
 	    if (!Cha_type[i].basic &&
-		strmatch3(Cha_form[i][j].name, JSTR_BASE_FORM,
-			  ESTR_BASE_FORM1, ESTR_BASE_FORM2))
+		(Cha_base_form_str
+		 ? !strcmp(Cha_form[i][j].name, Cha_base_form_str)
+		 : strmatch3(Cha_form[i][j].name, JSTR_BASE_FORM,
+			     ESTR_BASE_FORM1, ESTR_BASE_FORM2)))
 		Cha_type[i].basic = j;
 	    /*
 	     * gobi 
