@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: mmap.c,v 1.7.4.1 2001/06/24 06:19:02 taku-ku Exp $
+ * $Id: mmap.c,v 1.7.4.2 2002/01/05 07:05:34 kazuma-t Exp $
  */
 
 #include "config.h"
@@ -55,15 +55,6 @@
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-#ifdef HAVE_IO_H
-#include <io.h>
-#endif
-#ifdef HAVE_PROCESS_H
-#include <process.h>
-#endif
-#ifdef HAVE_WINSOCK2_H
-#include <winsock2.h>
-#endif
 
 #ifdef __MINGW32__
 #undef HAVE_MMAP
