@@ -36,7 +36,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Modified by: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Oct. 1996
- * $Id: parse.c,v 1.24.4.6 2001/06/21 05:37:36 masayu-a Exp $
+ * $Id: parse.c,v 1.24.4.7 2001/07/08 09:05:28 masayu-a Exp $
  */
 
 #include "chalib.h"
@@ -684,15 +684,13 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
      * ܽ
      */
     for (cursor = prev_cursor = 0; cursor < target_len;
-	cursor += cursor_sep(cursor, target_len - cursor)) {
-
-        prev_cursor = cursor;
-	/* skip annotations and white space */
-	while (cha_tok_anno_type(Cha_tokenizer, cursor) != 0 ) {
-	    cursor += cha_tok_char_type_len(Cha_tokenizer, cursor);
-	    if (cursor > target_len)
-		break;
-	}
+	cursor += cursor_sep(cursor, target_len - cursor),
+	prev_cursor = cursor) {
+        /* skip annotations and white space */
+	while (cha_tok_anno_type(Cha_tokenizer, cursor) != 0 )
+	  cursor += cha_tok_char_type_len(Cha_tokenizer, cursor);
+	if (cursor >= target_len)
+	  break;
 	
 	path_idx_num = collect_mrphs_for_pos(prev_cursor, path_idx);
 
@@ -727,7 +725,7 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
     if (mrph_idx % MRPH_NUM == 0 && malloc_mrph())
         goto error_end;
     
-    path_idx_num = collect_mrphs_for_pos(cursor, path_idx);
+    path_idx_num = collect_mrphs_for_pos(prev_cursor, path_idx);
 
     if (check_connect(cursor, mrph_idx - 1, path_idx) == FALSE)
         goto error_end;
