@@ -2,7 +2,7 @@
  *  SUFARY --- Suffix Array ΤΥ饤֥
  *  sufary.h - SUFARY饤֥إåե
  *
- * $Id: sufary.h,v 1.13 2001/03/16 04:06:17 kazuma-t Exp $
+ * $Id: sufary.h,v 1.13.4.1 2002/01/05 07:05:34 kazuma-t Exp $
  */
 
 #ifndef __SUFARY_H__
@@ -10,9 +10,6 @@
 
 #include "config.h"
 
-#ifdef HAVE_WINSOCK2_H
-#include <winsock2.h>
-#endif
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
