@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: tokenizer.c,v 1.5.6.1 2001/06/21 05:37:36 masayu-a Exp $
+ * $Id: tokenizer.c,v 1.5.6.2 2002/01/05 07:05:34 kazuma-t Exp $
  */
 
 #include <string.h>
@@ -158,7 +158,7 @@ cha_tok_parse(chasen_tok_t *tok, unsigned char *str, int len)
     tok->string = str;
     tok->string_len = len;
 
-    if (len > sizeof(tok->__static_char_type)) {
+    if (len > sizeof(tok->__static_char_type) / sizeof(int)) {
 	tok->_char_type = cha_malloc(sizeof(int) * len);
 	tok->_anno_type = cha_malloc(sizeof(int) * len);
 	tok->_is_malloced = 1;
