@@ -4,36 +4,43 @@
  * Read a sorted dictionary from stdin, and write an array for SUFARY
  * to stdout.
  *
- * $Id: convary.c,v 1.2 2000/12/06 18:01:16 kazuma-t Exp $
+ * $Id: convary.c,v 1.4 2001/03/16 04:06:17 kazuma-t Exp $
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/param.h>
+
+#include "htobe.h"
 
 char *prog_name;
 
-void usage(void)
+void
+usage(void)
 {
     printf("\
 Usage: convary < INPUT > OUTPUT\n");
     exit(1);
 }
 
-void eexit(void)
+void
+eexit(void)
 {
     perror(prog_name);
     exit(2);
 }
 
-void dump_offset(FILE *fp, long offset)
+void
+dump_offset(FILE * fp, long offset)
 {
-    offset = htonl(offset);
+    offset = htobe(offset);
     if (fwrite(&offset, sizeof(offset), 1, stdout) != 1)
 	eexit();
 }
 
-void convert(FILE *in, FILE *out)
+void
+convert(FILE * in, FILE * out)
 {
     int c;
     long offset, bol;
@@ -50,7 +57,8 @@ void convert(FILE *in, FILE *out)
 	eexit();
 }
 
-int main(int argc, char *argv[])
+int
+main(int argc, char *argv[])
 {
     prog_name = argv[0];
 
