@@ -4,7 +4,7 @@
  * Υץθϡ NLPRS '95 Invited Lecture Kenneth W. Church
  * ΤΤѤޤ 
  *
- * $Id: mkary.c,v 1.9.4.1 2001/06/24 06:19:02 taku-ku Exp $
+ * $Id: mkary.c,v 1.9.4.3 2002/01/08 07:13:14 taku-ku Exp $
  */
 
 #include "config.h"
@@ -119,7 +119,7 @@ open_array_file(char *fname)
 {
     FILE *ofd;
 
-    if ((ofd = fopen(fname, "w")) == NULL) {
+    if ((ofd = fopen(fname, "wb")) == NULL) {
 	cha_exit_perror(fname);
     }
     message("Save to \"%s\"\n", fname);
